/*
 * PIR sensor tester
 */

#include "notes.h"
#include <Adafruit_NeoPixel.h>
#ifdef __AVR__
 #include <avr/power.h> // Required for 16 MHz Adafruit Trinket
#endif

// Which pin on the Arduino is connected to the NeoPixels?
#define PIN        6 // On Trinket or Gemma, suggest changing this to 1

// How many NeoPixels are attached to the Arduino?
#define NUMPIXELS 16 // Popular NeoPixel ring size
Adafruit_NeoPixel pixels(NUMPIXELS, PIN, NEO_GRB + NEO_KHZ800);

int buzzer = 9;
int pir = A2;

bool isHot = false;  // temp
bool isBright = false;  // light
bool isMoving = false; // motion

#define DELAYVAL 500 // Time (in milliseconds) to pause between pixels

void setup() {
  // pinMode(ledPin, OUTPUT);      // declare LED as output
  // pinMode(inputPin, INPUT);     // declare sensor as input

  Serial.begin(9600);
 
  pixels.begin(); // INITIALIZE NeoPixel strip object (REQUIRED)

  Serial.println("Program starts ");
}

int melody[] = {
  // The Lick 
  NOTE_D4,8, NOTE_E4,8, NOTE_F4,8, NOTE_G4,8, NOTE_E4,4, NOTE_C4,8, NOTE_D4,1,
  
};

int notes = sizeof(melody) / sizeof(melody[0]) / 2;
int tempo = 140;
int wholenote = (60000 * 2) / tempo;

void playMelody() {
  for (int thisNote = 0; thisNote < notes * 2; thisNote = thisNote + 2) {
    int divider = melody[thisNote + 1];
    int noteDuration = (divider > 0) ? wholenote / divider : (wholenote / abs(divider)) * 1.5;
    tone(buzzer, melody[thisNote], noteDuration * 0.9);
    delay(noteDuration);
    noTone(buzzer);
  }
}
 
void loop(){
  // pixels.clear(); // Set all pixel colors to 'off'

  // The first NeoPixel in a strand is #0, second is 1, all the way up
  // to the count of pixels minus one.
  //for(int i=0; i<NUMPIXELS; i++) { // For each pixel...

    // pixels.Color() takes RGB values, from 0,0,0 up to 255,255,255
    // Here we're using a moderately bright green color:
    //pixels.setPixelColor(i, pixels.Color(0, 150, 0));

    //pixels.show();   // Send the updated pixel colors to the hardware.

    //delay(DELAYVAL); // Pause before next pass through loop
  //}

  float temp = analogRead(A0);
  temp = 100*temp/1023*5 - 50;
  if(temp > 20){
    isHot = true;
  }else{
    isHot = false;
  }

  Serial.print("\n temperature ");
  Serial.println(temp);

  float light = analogRead(A1);
  if(light > 950){
    isBright = true;
  }else{
    isBright = false;
  }
  Serial.print("\n light levels ");
  Serial.println(light);


  int motion = digitalRead(pir);
  if( motion == 1){
    isMoving = true;
  }
  else{
    isMoving = false;
  }
  Serial.print("\n Motion ");
  Serial.println(motion);  

  if (!isMoving && isHot && isBright){
    turnOnLED();
    playMelody();
  }
  else if(!isMoving && isHot){
    motionLED();
    tempLED();
  }
  else if(!isMoving && isBright){
    motionLED();
    lightLED();
  }
  else if(isHot && isBright){
    tempLED();
    lightLED();
  }
  else if (!isMoving){
    motionLED();

  } else if(isHot){
    tempLED();

  } else if(isBright){
    lightLED();
  }
  else {
    pixels.clear();
  }

  pixels.show();
  delay(500);

}

void turnOnLED(){
  motionLED();
  tempLED();
  lightLED();
}

void motionLED(){
  for(int i=0; i<6; i++) { // For each pixel...
    pixels.setPixelColor(i, pixels.Color(0, 255, 0));
  }
}

void tempLED(){
  for(int i=6; i<11; i++) { // For each pixel...
    pixels.setPixelColor(i, pixels.Color(0, 0, 255)); 
  }

}

void lightLED(){
  for(int i=11; i<16; i++) { // For each pixel...
      pixels.setPixelColor(i, pixels.Color(150, 0, 0));
    }
}